..
  This file describes user-visible changes between the versions.

  subsections could include these headings (in this order), omit if no content

    Notice
    Breaking Changes
    New Features and/or Enhancements
    Fixes
    Maintenance
    Deprecations
    Contributors

Change History
##############

..
   1.0.1
   ******

   release expected by 2023-01-05

1.0.0
******

Initial project release: 2022-11-26
